@@ -48,7 +48,6 @@ int byte_buffer_location=-1;
 int bit_buffer_read(int bits) {
         int retval;
         if (bits>bit_buffer_location) { 
-		DPRINTF("Request for %i bits, buffer contains %i bits",bits,bit_buffer_location);
 		bits=bit_buffer_location;
 	}
 
@@ -56,7 +55,6 @@ int bit_buffer_read(int bits) {
         bit_buffer_data=(bit_buffer_data<<bits);
 	bit_buffer_location-=bits;
 #ifdef BUFFER_VERBOSE
-	DPRINTF("bit_buffer_read(%i)=%i",bits,retval);
 #endif
         return(retval);
 }
@@ -73,18 +71,15 @@ int bit_buffer_read(int bits) {
 */
 void bit_buffer_write(unsigned int val, unsigned int bits) {
         while ((val>>bits)!=0) {
-                DPRINTF("Value (%i) is bigger than %i bits.",val,bits);
 		bits++;
         }
 
         if ((bits+bit_buffer_location)>(sizeof(bit_buffer_data)*8)) {
-                DPRINTF("Buffer overflow");
                 return;
         }
         bit_buffer_location+=bits;
         bit_buffer_data+=(val<<((sizeof(bit_buffer_data)*8)-bit_buffer_location));
 #ifdef BUFFER_VERBOSE
-	DPRINTF("bit_buffer_write(%i, %i)",val,bits);
 #endif
         return;
 }
@@ -99,7 +94,6 @@ void bit_buffer_write(unsigned int val, unsigned int bits) {
 */
 int bit_buffer_size(void) {
 #ifdef BUFFER_VERBOSE
-	DPRINTF("bit_buffer_size()=%i",bit_buffer_location);
 #endif
         return(bit_buffer_location);
 }
@@ -115,7 +109,6 @@ void bit_buffer_purge(void) {
         bit_buffer_location=0;
         bit_buffer_data=0;
 #ifdef BUFFER_VERBOSE
-	DPRINTF("bit_buffer_purge()");
 #endif
         return;
 }
@@ -125,7 +118,6 @@ char *byte_buffer_read(int bytes) {
 	char *retval;
 	if (byte_buffer_location==-1) return(NULL);
 	if (bytes>byte_buffer_location) {
-		DPRINTF("Request for %i bytes, buffer contains %i bytes.",bytes,byte_buffer_location);
 		bytes=byte_buffer_location;
 	}
 	if (!(retval=malloc(bytes))) {
@@ -142,7 +134,6 @@ void byte_buffer_write(char *val, unsigned int size) {
 		byte_buffer_purge();
 	}
 	if ((byte_buffer_location+size)>(BYTE_BUFF_SIZE)) {
-		DPRINTF("Buffer overflow.");
 		return;
 	}
 	memcpy(byte_buffer_data+byte_buffer_location,val,size);
