@@ -24,8 +24,8 @@
 #if defined(USE_MODULES) && !defined(AS_MODULE)
 #define comp_factor_algo DACT_FAILED_ALGO
 #else
-int comp_factor_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
-int comp_factor_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
-int comp_factor_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
+int comp_factor_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size, int buf_size);
+int comp_factor_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size, int buf_size);
+int comp_factor_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size, int buf_size);
 #endif
 #endif
