@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001  Roy Keene
+ * Copyright (C) 2001, 2002, and 2003  Roy Keene
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,5 +22,6 @@
 #define _CRC_H
 #include "dact.h"
 
-uint32_t ELFCRC(const uint32_t start, const unsigned char *name, const uint32_t n);
+uint32_t elfcrc(const uint32_t start, const unsigned char *name, const uint32_t n);
+uint32_t crc(const uint32_t prev, unsigned char *val, const uint32_t n);
 #endif
