@@ -37,8 +37,8 @@
 
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 8
-#define DACT_VER_REVISION 41
-#define DACT_VERSION "0.8.41"
+#define DACT_VER_REVISION 42
+#define DACT_VERSION "0.8.42"
 #ifdef DEBUG
 #define DACT_VER_SUB	"dev"
 #else
@@ -211,8 +211,8 @@
 
 
 int print_help(int argc, char **argv);
-int dact_upgrade_file_checkver(const char *name, const char *url_ver, const char *options);
-int dact_upgrade_file(const char *name, const char *url_get, const char *url_ver, uint32_t version, const char *dest, const char *options);
+int dact_upgrade_file_checkver(const char *name, const char *url_ver, const unsigned char *options);
+int dact_upgrade_file(const char *name, const char *url_get, const char *url_ver, uint32_t version, const char *dest, const unsigned char *options);
 int dact_shutdown(int retval);
 char *dact_getoutfilename(const char *orig, const int mode, const char *ext);
 int main(int argc, char **argv);
